@@ -34,6 +34,7 @@ def parse(html: str, p: Product):
     parse_delivery(p, selector=sel)
     parse_material(p, selector=sel)
     parse_description(p, selector=sel)
+    parse_title(p, selector=sel)
 
 
 def parse_parent_asin(p: Product, html: str = None, selector: parsel.Selector = None):
@@ -209,3 +210,8 @@ def parse_description(p: Product, html: str = None, selector: parsel.Selector =
     for t in texts:
         desc.append(t.strip())
     p.description = desc
+
+
+def parse_title(p: Product, html: str = None, selector: parsel.Selector = None):
+    title = selector.xpath("normalize-space(//span[@id='productTitle']/text())").get()
+    p.title = title
